ptr

package
v7.15.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 14, 2026 License: MIT Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Deref

func Deref[T any](p *T, def T) T

Deref returns the value of the pointer or def(ault) if nil.

func To

func To[T any](v T) *T

To generically returns a pointer to the given value.

Types

This section is empty.

Jump to